#
# spec file for package antlr-bootstrap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gccbinsuffix %(rpm -q --qf "-%%{VERSION}" gcc-java)
%define real_name antlr
Name:           antlr-bootstrap
VCS: https://src.suse.de/SLFO-pool/antlr#42c9fd855c658f9ef79e22abe5e725ff6b4d577613a47c37e72a1ddf1f499657
Version:        2.7.7
Release:        160000.3.4
Summary:        Antlr for bootstrapping purposes
License:        BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/Libraries/Java
URL:            https://www.antlr.org
Source0:        antlr-%{version}.tar.bz2
Source1:        manifest.antlr
BuildRequires:  java-devel >= 1.8
BuildArch:      noarch

%description
This antlr package is used for bootstrapping purposes only.

%prep
%setup -q -n %{real_name}-%{version}
find | grep "\(ShowString.java$\|StreamConverter.java$\)" && exit 42 || :

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
#>>> some useful functions ... used throughout bootstrap packages
# variables:
TARGET_DIR=`pwd`
CLASSPATH_ORIG="$CLASSPATH"
#>>> delete binary file and files not needed
function delBinaryFiles() {
  set +x
  echo deleting binary files ...
  find . -name "*.class" -o -name "*.jar" -o -name "*DELETED-BY-PACKAGER*" -delete
  set -x
}
#>>> make %{?_smp_mflags} a string with all jar files found in target folder that can be used for a classpath string
# string is saved in JAR_CLASSPATH
function mkTargetClasspath() {
  set +x
  JAR_CLASSPATH=""
  for file in `find %{_javadir} -name "*.jar"`
  do
    JAR_CLASSPATH=$file:$JAR_CLASSPATH
  done
  set -x
}
#>>> compiles all *.java file in the current directory tree
# uses mkTargetClasspath for CLASSPATH  variable
function compileFiles() {
  mkTargetClasspath
  set +x
  COMPILE_CLASSPATH_PATH=.:${JAR_CLASSPATH}
  echo -e "$COMPILER_COMMAND $COMPILE_CLASSPATH_PATH $(find . -name "*.java" | xargs)"
  $COMPILER_COMMAND $COMPILE_CLASSPATH_PATH $(find . -name "*.java" | xargs)
  # check for errors
  if [ $? != 0 ]
  then
    echo ERROR
    exit 1;
  fi
  echo done
  set -x
}
#>>> make %{?_smp_mflags} jar archive
# PARAM#1: name of jar archive (without .jar suffix)
# uses $TARGET_DIR to move created jar to
function mkJar() {
  jar  \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 17}%{!?pkg_vcmp:0}
    --date="$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)" \
%endif
    --create --file=${1}.jar --manifest=$(ls manifest.*) \
  $(find  -name "version.txt" -or -name "*.class" -or -name "*.properties" -or -name "*.rsc" |\
    xargs) ;
  mv ${1}.jar $TARGET_DIR
}
COMPILER_COMMAND="javac -source 8 -target 8 -cp  "
delBinaryFiles
mkdir src
mv antlr src
cd src
cp %{SOURCE1} .
compileFiles
mkJar %{name}
delBinaryFiles

%install
install -d -m 0755 %{buildroot}%{_javadir}
install -m 0644 %{name}.jar %{buildroot}%{_javadir}/

%files
%{_javadir}/%{name}.jar

%changelog
* Tue Oct  1 2024 fstrba@suse.com
- Use SOURCE_DATE_EPOCH for reproducible builds
* Tue Oct 17 2023 fstrba@suse.com
- Clean the spec file and use javapackages-local >= 6 features
* Thu May  4 2023 fcrozat@suse.com
- Add _multibuild to define additional spec files as additional
  flavors.
  Eliminates the need for source package links in OBS.
* Fri Aug  2 2019 mliska@suse.cz
- Use FAT LTO objects in order to provide proper static library.
* Thu May  9 2019 bwiedemann@suse.com
- Drop unused BuildRequires: zip+unzip
* Fri Feb  1 2019 fstrba@suse.com
- Speed-up build by compiling all *.java files in one javac
  invocation
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Mon Oct  9 2017 fstrba@suse.com
- Remove requirement of gcc-java all together and build with
  any java version that exists and is able to use source and target
  1.6
* Wed Sep 20 2017 fstrba@suse.com
- Remove requirements of ecj-bootstrap and fastjar
  * use the gcj.jar that comes with gccN-java
  * use gjar-N instead of fastjar
* Fri Jul  4 2014 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
* Wed Jul 17 2013 schwab@suse.de
- Fix quoting of $
* Tue Aug 31 2010 mvyskocil@suse.cz
- Do not install antlr.jar to avoid conflicts with a regular
  antlr-java packages. Packages using antlr-bootstrap needs to have
  antlr-bootstrap in their CLASSPATH
* Mon Aug 23 2010 mvyskocil@suse.cz
- do not Provide antlr
* Mon Mar  3 2008 mvyskocil@suse.cz
- updated to 2.7.7
* Wed Jan 30 2008 adrian@suse.de
- add Provides: antlr on sugggestion of dbornkessel
* Fri May  4 2007 dbornkessel@suse.de
- added unzip to BuildRequires
* Wed Nov 15 2006 dbornkessel@suse.de
- delete "Provides: antlr" ... packages that need the bootstrap package should have a hard require on it
* Thu Oct 12 2006 ro@suse.de
- change buildreq to ">=" for ecj-bootstrap
* Sat Oct  7 2006 dbornkessel@suse.de
- added check that checks whether deleted files ShowString.java and StreamConverter.java are really not in place
* Thu Oct  5 2006 dbornkessel@suse.de
- deleted
  antlr-2.7.6/examples/java/unicode.IDENTs/ShowString.java
  antlr-2.7.6/examples/java/unicode.IDENTs/StreamConverter.java
  from tar ball due to licensing issues (Bug #207621)
* Wed Sep 27 2006 ro@suse.de
- added gcc-gij to BuildRequires
* Wed Sep 20 2006 dbornkessel@suse.de
- renamed antlr-bootstrap.jar to antlr.jar
* Mon Sep 18 2006 dbornkessel@suse.de
- created bootstrapping package
